pub enum GraphKind {
All,
CodeOnly,
TypesOnly,
}Expand description
The kind of module graph.
Variants
All
All types of dependencies should be analyzed and included in the graph.
CodeOnly
Only code dependencies should be analyzed and included in the graph. This is useful when transpiling and running code, but not caring about type only dependnecies.
TypesOnly
Only type dependencies should be analyzed and included in the graph. This is useful when assessing types, like documentation or type checking, when the code will not be executed.
Note that code which is overloaded with types upon access (like the
X-TypeScript-Types header or types defined in the code itself) will
still be loaded into the graph, but further code only dependencies will
not be followed.
Implementations
Sourceimpl GraphKind
impl GraphKind
pub fn include_types(&self) -> bool
pub fn include_code(&self) -> bool