Module source

Module source 

Modules

wasm

Structs

CacheInfo
Information that comes from an external source which can be optionally included in the module graph.
ChecksumIntegrityError
DefaultJsrUrlProvider
HashMapLocker
LoadOptions
LoaderChecksum
A SHA-256 checksum to verify the contents of a module with while loading.
MemoryLoader
An implementation of the loader attribute where the responses are provided ahead of time. This is useful for testing or
NpmResolvePkgReqsResult
NullFileSystem
NullModuleInfoCacher

Enums

CacheResponse
CacheSetting
LoadError
LoadResponse
The response that is expected from a loader’s .load() method.
ResolutionKind
The kind of resolution currently being done by deno_graph.
ResolutionMode
ResolveError
A source entry used by MemoryLoader.

Constants

DEFAULT_JSX_IMPORT_SOURCE_MODULE

Statics

DEFAULT_JSR_URL

Traits

JsrUrlProvider
Loader
A trait which allows asynchronous loading of source files into a module graph in a thread safe way as well as a way to provide additional meta data about any cached resources.
Locker
ModuleInfoCacher
NpmResolver
Reporter
A trait which can be used to allow the module graph to report status events to the user.
Resolver
A trait which allows the module graph to resolve specifiers and type only dependencies. This can be use to provide import maps and override other default resolution logic used by deno_graph.

Functions

load_data_url
recommended_registry_package_url
The recommended way for getting the registry URL for a package.
recommended_registry_package_url_to_nv
The recommended way to get the package name and version from a URL that is found on the registry.
resolve_media_type_and_charset_from_content_type
Resolve a media type and optionally the charset from a module specifier and the value of a content type header.
resolve_media_type_and_charset_from_headers
Resolve a media type and optionally the charset from a module specifier and the value of a content type header.

Type Aliases

EnsureCachedFuture
EnsureCachedResult
FileSystem
LoadFuture
LoadResult
MemoryLoaderSources
In-memory sources passed to MemoryLoader::new.