pub struct BuildOptions<'a> {
    pub is_dynamic: bool,
    pub imports: Vec<ReferrerImports>,
    pub file_system: Option<&'a dyn FileSystem>,
    pub resolver: Option<&'a dyn Resolver>,
    pub npm_resolver: Option<&'a dyn NpmResolver>,
    pub module_analyzer: Option<&'a dyn ModuleAnalyzer>,
    pub module_parser: Option<&'a dyn ModuleParser>,
    pub reporter: Option<&'a dyn Reporter>,
    pub workspace_fast_check: bool,
    pub workspace_members: Vec<WorkspaceMember>,
}

Fields

is_dynamic: boolimports: Vec<ReferrerImports>

Additional imports that should be brought into the scope of the module graph to add to the graph’s “imports”. This may be extra modules such as TypeScript’s “types” option or JSX runtime types.

file_system: Option<&'a dyn FileSystem>resolver: Option<&'a dyn Resolver>npm_resolver: Option<&'a dyn NpmResolver>module_analyzer: Option<&'a dyn ModuleAnalyzer>module_parser: Option<&'a dyn ModuleParser>reporter: Option<&'a dyn Reporter>workspace_fast_check: bool

Whether to fill workspace members with fast check TypeScript data.

workspace_members: Vec<WorkspaceMember>