pub async fn parse_module(
options: ParseModuleOptions<'_>,
) -> Result<Module, ModuleError>Expand description
Parse an individual module, returning the module as a result, otherwise erroring with a module graph error.
pub async fn parse_module(
options: ParseModuleOptions<'_>,
) -> Result<Module, ModuleError>Parse an individual module, returning the module as a result, otherwise erroring with a module graph error.