Modules
Structs
- Cache
Info - Information that comes from an external source which can be optionally included in the module graph.
- Checksum
Integrity Error - Default
JsrUrl Provider - Hash
MapLocker - Load
Options - Loader
Checksum - A SHA-256 checksum to verify the contents of a module with while loading.
- Memory
Loader - An implementation of the loader attribute where the responses are provided ahead of time. This is useful for testing or
- NpmResolve
PkgReqs Result - Null
File System - Null
Module Info Cacher
Enums
- Cache
Response - Cache
Setting - Load
Error - Load
Response - The response that is expected from a loader’s
.load()method. - Resolution
Kind - The kind of resolution currently being done by deno_graph.
- Resolution
Mode - Resolve
Error - Source
- A source entry used by
MemoryLoader.
Constants
Statics
Traits
- JsrUrl
Provider - Loader
- A trait which allows asynchronous loading of source files into a module graph in a thread safe way as well as a way to provide additional meta data about any cached resources.
- Locker
- Module
Info Cacher - NpmResolver
- Reporter
- A trait which can be used to allow the module graph to report status events to the user.
- Resolver
- A trait which allows the module graph to resolve specifiers and type only
dependencies. This can be use to provide import maps and override other
default resolution logic used by
deno_graph.
Functions
- load_
data_ url - recommended_
registry_ package_ url - The recommended way for getting the registry URL for a package.
- recommended_
registry_ package_ url_ to_ nv - The recommended way to get the package name and version from a URL that is found on the registry.
- resolve_
media_ type_ and_ charset_ from_ content_ type - Resolve a media type and optionally the charset from a module specifier and the value of a content type header.
- resolve_
media_ type_ and_ charset_ from_ headers - Resolve a media type and optionally the charset from a module specifier and the value of a content type header.
Type Aliases
- Ensure
Cached Future - Ensure
Cached Result - File
System - Load
Future - Load
Result - Memory
Loader Sources - In-memory sources passed to
MemoryLoader::new.